about summary refs log tree commit diff
path: root/maintainers
diff options
context:
space:
mode:
Diffstat (limited to 'maintainers')
-rwxr-xr-xmaintainers/scripts/travis-nox-review-pr.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/maintainers/scripts/travis-nox-review-pr.sh b/maintainers/scripts/travis-nox-review-pr.sh
index 649798ec76b02..4da4f7dacfae6 100755
--- a/maintainers/scripts/travis-nox-review-pr.sh
+++ b/maintainers/scripts/travis-nox-review-pr.sh
@@ -53,8 +53,8 @@ while test -n "$1"; do
         nox)
             echo "=== Fetching Nox from binary cache"
 
-            # build nox silently so it's not in the log
-            nix-build "<nixpkgs>" -A nox -A stdenv
+            # build nox (+ a basic nix-shell env) silently so it's not in the log
+            nix-shell -p nox stdenv --command true
             ;;
 
         pr)